@@ -30,13 +30,13 @@ from matplotlib import image
 from neptune_xgboost import __version__
 
 try:
-    # neptune-client=0.9.0 package structure
+    # neptune-client=0.9.0+ package structure
     import neptune.new as neptune
-    from neptune.new.internal.utils import verify_type
+    from neptune.new.integrations.utils import verify_type, expect_not_an_experiment
 except ImportError:
-    # neptune-client=1.0.0 package structure
+    # neptune-client>=1.0.0 package structure
     import neptune
-    from neptune.internal.utils import verify_type
+    from neptune.integrations.utils import verify_type, expect_not_an_experiment
 
 INTEGRATION_VERSION_KEY = "source_code/integrations/neptune-xgboost"
 
@@ -163,6 +163,7 @@ class NeptuneCallback(xgb.callback.TrainingCallback):
                  log_tree=None,
                  tree_figsize=30):
 
+        expect_not_an_experiment(run)
         verify_type("run", run, neptune.Run)
         verify_type("base_namespace", base_namespace, str)
         log_model is not None and verify_type("log_model", log_model, bool)
@@ -290,5 +291,15 @@ class NeptuneCallback(xgb.callback.TrainingCallback):
             config = json.loads(model.cvfolds[0].bst.save_config())
         else:
             config = json.loads(model.save_config())
-        lr = config["learner"]["gradient_booster"]["updater"]["grow_colmaker"]["train_param"]["learning_rate"]
-        self.run["learning_rate"].log(float(lr))
+
+        lr = None
+        updater = config["learner"]["gradient_booster"]["updater"]
+        updater_types = ['grow_colmaker', 'grow_histmaker', 'grow_local_histmaker', 'grow_quantile_histmaker',
+                         'grow_gpu_hist', 'sync', 'refresh', 'prune']
+        for updater_type in updater_types:
+            if updater_type in updater:
+                lr = updater[updater_type]["train_param"]["learning_rate"]
+                break
+
+        if lr is not None:
+            self.run["learning_rate"].log(float(lr))
